==> mingw-w64-freecad-0.21.2-7.src.tar.zst: FreeCAD-0.21.2/src/Mod/Tux/Resources/translations/Tux_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Select</source>
      <translation>Επιλέξτε</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Zoom</source>
      <translation>Εστίαση</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotate</source>
      <translation>Περιστρέψτε</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Pan</source>
      <translation>Μεταφορική Κίνηση Κάμερας</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Tilt</source>
      <translation>Ρύθμιση Κλίσης Κάμερας</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="72"/>
      <source>Navigation style</source>
      <translation>Τύπος Πλοήγησης</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="73"/>
      <source>Page Up or Page Down key.</source>
      <translation>Το πλήκτρο Μετακίνησης της Σελίδας προς τα Πάνω ή προς τα Κάτω.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Rotation focus</source>
      <translation>Άξονας περιστροφής</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="75"/>
      <source>Middle mouse button or H key.</source>
      <translation>Μεσαίο πλήκτρο του ποντικιού ή πλήκτρο H.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="77"/>
      <source>Middle mouse button.</source>
      <translation>Μεσαίο πλήκτρο του ποντικιού.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="80"/>
      <source>Navigation style not recognized.</source>
      <translation>Ο τύπος πλοήγησης δεν αναγνωρίζεται.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="331"/>
      <source>Settings</source>
      <translation>Ρυθμίσεις</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="332"/>
      <source>Orbit style</source>
      <translation>Τύπος μορφοποίησης τροχιάς</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="333"/>
      <source>Compact</source>
      <translation>Συμπαγής</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="334"/>
      <source>Tooltip</source>
      <translation>Επεξήγηση εργαλείου</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="335"/>
      <source>Turntable</source>
      <translation>Περιστρεφόμενη βάση</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="336"/>
      <source>Free Turntable</source>
      <translation type="unfinished">Free Turntable</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="337"/>
      <source>Trackball</source>
      <translation>Ιχνόσφαιρα</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="338"/>
      <source>Undefined</source>
      <translation>Απροσδιόριστο</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0rc2-3.src.tar.zst: FreeCAD-1.0rc2/src/Mod/Tux/Resources/translations/Tux_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="93"/>
      <source>Select</source>
      <translation>Επιλέξτε</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="94"/>
      <source>Zoom</source>
      <translation>Εστίαση</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="95"/>
      <source>Rotate</source>
      <translation>Περιστρέψτε</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="96"/>
      <source>Pan</source>
      <translation>Μεταφορική Κίνηση Κάμερας</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="97"/>
      <source>Tilt</source>
      <translation>Ρύθμιση Κλίσης Κάμερας</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="98"/>
      <source>Navigation style</source>
      <translation>Τύπος Πλοήγησης</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="99"/>
      <source>Page Up or Page Down key.</source>
      <translation>Το πλήκτρο Μετακίνησης της Σελίδας προς τα Πάνω ή προς τα Κάτω.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="100"/>
      <source>Rotation focus</source>
      <translation>Άξονας περιστροφής</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="101"/>
      <source>Middle mouse button or H key.</source>
      <translation>Μεσαίο πλήκτρο του ποντικιού ή πλήκτρο H.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="103"/>
      <source>Middle mouse button.</source>
      <translation>Μεσαίο πλήκτρο του ποντικιού.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="106"/>
      <source>Navigation style not recognized.</source>
      <translation>Ο τύπος πλοήγησης δεν αναγνωρίζεται.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="577"/>
      <source>Settings</source>
      <translation>Ρυθμίσεις</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="578"/>
      <source>Orbit style</source>
      <translation>Τύπος μορφοποίησης τροχιάς</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="579"/>
      <source>Compact</source>
      <translation>Συμπαγής</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="580"/>
      <source>Tooltip</source>
      <translation>Επεξήγηση εργαλείου</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="581"/>
      <source>Turntable</source>
      <translation>Περιστρεφόμενη βάση</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="582"/>
      <source>Free Turntable</source>
      <translation>Ελεύθερη Περιστροφική πλάκα</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="583"/>
      <source>Trackball</source>
      <translation>Ιχνόσφαιρα</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="584"/>
      <source>Undefined</source>
      <translation>Απροσδιόριστο</translation>
    </message>
  </context>
</TS>
